reuse.covered_files module - reuse 6.1.2 documentation

Skip to content
Back to top
View this page

# reuse.covered_files module

The REUSE Specification has a concept called Covered Files; files which must contain licensing information. Some files in a project are not Covered Files, and thus needn’t contain licensing information. This module contains all that logic.

reuse.covered_files.is_path_ignored(path: Path, subset_files: Collection[str | PathLike[str]] | None = None, include_submodules: bool = False, include_meson_subprojects: bool = False, include_reuse_tomls: bool = False, vcs_strategy: VCSStrategy | None = None) → bool

  Is path ignored by some mechanism?

reuse.covered_files.iter_files(directory: str | PathLike[str], subset_files: Collection[str | PathLike[str]] | None = None, include_submodules: bool = False, include_meson_subprojects: bool = False, include_reuse_tomls: bool = False, vcs_strategy: VCSStrategy | None = None) → Generator[Path, None, None]

  Yield all Covered Files in directory and its subdirectories according to the REUSE Specification.